==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebHeadSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescriptionMetadata } from "./WebHeadSelectorTemplateDetailsDescriptionMetadata";
import { WebHeadSelectorTemplateContextDescription } from "./WebHeadSelectorTemplateContextDescription";
/**
 * @hidden
 */
export let WebHeadSelectorTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeadSelectorTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeadSelectorTemplateContextDescriptionMetadata.a == null) {
                WebHeadSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeadSelectorTemplateContextDescriptionMetadata.c(WebHeadSelectorTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebHeadSelectorTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebHeadSelectorTemplateContextDescriptionMetadata.a);
            WebHeadSelectorTemplateDetailsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeadSelectorTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "ExportedType:WebHeadSelectorTemplateDetails");
        }
        static d(a) {
            WebHeadSelectorTemplateContextDescriptionMetadata.b(a);
            a.aa("WebHeadSelectorTemplateContext", () => new WebHeadSelectorTemplateContextDescription());
            a.z("WebHeadSelectorTemplateContext", WebHeadSelectorTemplateContextDescriptionMetadata.a);
        }
    }
    WebHeadSelectorTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebHeadSelectorTemplateContextDescriptionMetadata, 'WebHeadSelectorTemplateContextDescriptionMetadata');
    WebHeadSelectorTemplateContextDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebHeadSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescriptionMetadata } from "./WebHeadSelectorTemplateDetailsDescriptionMetadata";
import { WebHeadSelectorTemplateContextDescription } from "./WebHeadSelectorTemplateContextDescription";
/**
 * @hidden
 */
export let WebHeadSelectorTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeadSelectorTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeadSelectorTemplateContextDescriptionMetadata.a == null) {
                WebHeadSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeadSelectorTemplateContextDescriptionMetadata.c(WebHeadSelectorTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebHeadSelectorTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebHeadSelectorTemplateContextDescriptionMetadata.a);
            WebHeadSelectorTemplateDetailsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeadSelectorTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebHeadSelectorTemplateDetails");
        }
        static d(a) {
            WebHeadSelectorTemplateContextDescriptionMetadata.b(a);
            a.ac("WebHeadSelectorTemplateContext", () => new WebHeadSelectorTemplateContextDescription());
            a.ab("WebHeadSelectorTemplateContext", WebHeadSelectorTemplateContextDescriptionMetadata.a);
        }
    }
    WebHeadSelectorTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebHeadSelectorTemplateContextDescriptionMetadata, 'WebHeadSelectorTemplateContextDescriptionMetadata');
    WebHeadSelectorTemplateContextDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateContextDescriptionMetadata;
})();
